<?php
// NO iniciar sesión aquí todavía, lo haremos después de verificar
// session_start();

// Habilitar reporte de errores para depuración (Desactivar en producción)
// ini_set('display_errors', 1);
// ini_set('display_startup_errors', 1);
// error_reporting(E_ALL);

// Establecer encabezado JSON para la respuesta
header('Content-Type: application/json');

// Incluir Composer autoload y config DB
require_once 'vendor/autoload.php';
require_once 'config.php'; // Tu script de conexión a la BD ($conn)

// Importar clases de Firebase Admin SDK
use Kreait\Firebase\Factory;
use Kreait\Firebase\Exception\Auth\IdTokenVerificationFailed;
use Kreait\Firebase\Exception\Auth\UserNotFound; // Podría ser útil

// --- Validación Inicial ---
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => 'Método no permitido.']);
    exit;
}

$idToken = $_POST['idToken'] ?? '';
$name = trim($_POST['name'] ?? '');
$password = $_POST['password'] ?? ''; // Contraseña en texto plano

if (empty($idToken) || empty($name) || empty($password)) {
    echo json_encode(['success' => false, 'message' => 'Faltan datos requeridos (token, nombre, contraseña).']);
    exit;
}

if (strlen($password) < 6) {
    echo json_encode(['success' => false, 'message' => 'La contraseña es demasiado corta (mínimo 6 caracteres).']);
    exit;
}


// --- Verificación del Token con Firebase Admin ---
$serviceAccountPath = '/ruta/absoluta/a/tu/serviceAccountKey.json'; // ¡¡¡CAMBIA ESTO!!!

if (!file_exists($serviceAccountPath)) {
     error_log("Archivo de cuenta de servicio Firebase no encontrado en: " . $serviceAccountPath);
     echo json_encode(['success' => false, 'message' => 'Error de configuración del servidor [Firebase Admin].']);
     exit;
}

try {
    $factory = (new Factory)->withServiceAccount($serviceAccountPath);
    $auth = $factory->createAuth();

    // Verifica el ID Token. Si falla, lanza una excepción.
    $verifiedIdToken = $auth->verifyIdToken($idToken, true); // El true fuerza chequeo de revocación

    // Obtiene datos del token verificado
    $uid = $verifiedIdToken->claims()->get('sub'); // UID de Firebase
    $phone = $verifiedIdToken->claims()->get('phone_number'); // ¡Número verificado!

    if (empty($phone)) {
        // Esto no debería pasar si Phone Auth fue el método, pero por si acaso
        throw new Exception("El token verificado no contiene número de teléfono.");
    }

    // --- Lógica de Base de Datos ---

    // 1. Verificar si el teléfono YA existe en nuestra BD y está verificado
    //    (Doble chequeo por si acaso, aunque el flujo normal es para nuevos)
    $stmt_check = $conn->prepare("SELECT id FROM users WHERE phone = ? AND is_verified = 1");
    if(!$stmt_check){
         error_log("Error preparando stmt_check: ".$conn->error);
         throw new Exception("Error interno del servidor [DB Check]");
    }
    $stmt_check->bind_param("s", $phone);
    $stmt_check->execute();
    $result_check = $stmt_check->get_result();

    if ($result_check->num_rows > 0) {
        $stmt_check->close();
        echo json_encode(['success' => false, 'message' => 'Este número de teléfono ya está registrado y verificado. Intenta iniciar sesión.']);
        $conn->close();
        exit;
    }
    $stmt_check->close();

     // 2. Hashear la contraseña
     $hashed_password = password_hash($password, PASSWORD_DEFAULT);
     if ($hashed_password === false) {
          error_log("Error al hashear la contraseña para el teléfono: ".$phone);
          throw new Exception("Error interno del servidor [Password Hash]");
     }

    // 3. Insertar el NUEVO usuario como VERIFICADO
    $insert_query = "INSERT INTO users (phone, name, password, is_verified, created_at, last_login) VALUES (?, ?, ?, 1, NOW(), NOW())
                     ON DUPLICATE KEY UPDATE name = VALUES(name), password = VALUES(password), is_verified = 1, last_login = NOW()";
                     // Usamos ON DUPLICATE KEY UPDATE por si acaso el check anterior falló o hubo concurrencia,
                     // actualizando los datos y marcando como verificado si existía pero no lo estaba.

    $stmt_insert = $conn->prepare($insert_query);
     if(!$stmt_insert){
         error_log("Error preparando stmt_insert: ".$conn->error);
         throw new Exception("Error interno del servidor [DB Insert]");
    }
    $stmt_insert->bind_param("sss", $phone, $name, $hashed_password);

    if ($stmt_insert->execute()) {
        $user_id = $conn->insert_id;
         if ($user_id === 0) { // Si se ejecutó ON DUPLICATE KEY UPDATE, insert_id es 0, necesitamos obtener el ID real
             $stmt_get_id = $conn->prepare("SELECT id FROM users WHERE phone = ?");
              if($stmt_get_id){
                 $stmt_get_id->bind_param("s", $phone);
                 $stmt_get_id->execute();
                 $result_id = $stmt_get_id->get_result();
                 $user_row = $result_id->fetch_assoc();
                 $user_id = $user_row['id'];
                 $stmt_get_id->close();
              } else {
                  error_log("Error obteniendo ID después de ON DUPLICATE KEY UPDATE para: ".$phone." Error: ".$conn->error);
                   // Continuamos sin el ID exacto para la sesión por ahora, pero logueamos el error
              }
         }

        $stmt_insert->close();

        if (!$user_id) {
             error_log("No se pudo obtener user_id después de insertar/actualizar para: ".$phone);
              throw new Exception("Error interno del servidor [User ID]");
        }

        // 4. Iniciar sesión PHP
        session_start(); // Iniciar sesión AHORA que está verificado y guardado
        $_SESSION['user_id'] = $user_id;
        $_SESSION['name'] = $name;
        $_SESSION['phone'] = $phone; // Guardar teléfono verificado

        // 5. Actualizar estado online (tu lógica)
        $update_status_query = "INSERT INTO user_status (user_id, status, last_activity) VALUES (?, 'online', NOW()) ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()";
        $status_stmt = $conn->prepare($update_status_query);
        if ($status_stmt) {
             $status_stmt->bind_param("i", $user_id);
             $status_stmt->execute();
             $status_stmt->close();
        } else {
             error_log("Error preparando update_status_query post-registro para user_id ".$user_id.": ".$conn->error);
             // No bloqueamos la respuesta por esto, pero lo logueamos
        }


        // 6. Enviar respuesta de éxito al frontend
        echo json_encode(['success' => true, 'redirect' => 'dashboard.php']); // O la URL a la que quieres redirigir

    } else {
         // Error en la ejecución del INSERT/UPDATE
         error_log("Error ejecutando INSERT/UPDATE para: ".$phone.". Error: " . $stmt_insert->error);
         $stmt_insert->close();
          // Verificar si fue por duplicado (aunque ON DUPLICATE debería manejarlo)
          if ($conn->errno == 1062) {
               echo json_encode(['success' => false, 'message' => 'Este número de teléfono ya parece estar registrado. Intenta iniciar sesión.']);
          } else {
              throw new Exception("Error al guardar los datos del usuario en la base de datos.");
          }
    }


} catch (IdTokenVerificationFailed $e) {
    error_log("Firebase Token Verification Failed: " . $e->getMessage());
    echo json_encode(['success' => false, 'message' => 'La verificación del teléfono falló (token inválido o expirado). Intenta registrarte de nuevo.']);
} catch (Exception $e) {
    // Captura excepciones generales (configuración, BD, etc.)
    error_log("Error en finalize_registration.php: " . $e->getMessage());
    // No mostrar $e->getMessage() directamente al usuario en producción por seguridad
    echo json_encode(['success' => false, 'message' => 'Ocurrió un error inesperado al completar el registro. Por favor, inténtalo más tarde.']);
} finally {
    // Asegurarse de cerrar la conexión
    if (isset($conn) && $conn instanceof mysqli) {
        $conn->close();
    }
}

exit; // Terminar script
?>