<?php
session_start();
require_once 'config.php'; // Mover conexión aquí

// Redirigir si ya está autenticado
if (isset($_SESSION['user_id'])) {
    header('Location: dashboard.php');
    exit();
}

$error = '';
$action = $_POST['action'] ?? 'show_forms';

// --- Lógica de Procesamiento POST (SOLO LOGIN) ---
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'login') {

    $country_code = isset($_POST['country_code']) ? $conn->real_escape_string($_POST['country_code']) : '57';
    $phone_number = isset($_POST['phone']) ? $conn->real_escape_string($_POST['phone']) : '';
    $password = isset($_POST['password']) ? $_POST['password'] : '';

    // Formatear número de teléfono
    $phone = '';
    if ($phone_number) {
        if (strpos($phone_number, '+') === 0) {
            $phone = $conn->real_escape_string($phone_number);
        } else {
            $phone = '+' . $country_code . $phone_number;
            $phone = $conn->real_escape_string($phone);
        }
    }

    if (empty($phone) || empty($password)) {
        $error = "Teléfono y contraseña son requeridos para iniciar sesión.";
    } else {
        // Buscar usuario por teléfono
        $query = "SELECT id, name, password, is_verified FROM users WHERE phone = ?";
        $stmt = $conn->prepare($query);
        if (!$stmt) {
            error_log("Error preparando consulta de login: " . $conn->error);
            $error = "Error del servidor. Inténtalo más tarde.";
        } else {
            $stmt->bind_param("s", $phone);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                $user = $result->fetch_assoc();

                // Verificar si la cuenta está verificada (ahora es importante)
                if (!$user['is_verified']) {
                    $error = "Tu número de teléfono no ha sido verificado. Por favor, completa el proceso de registro si eres nuevo, o contacta soporte.";
                }
                // Verificar contraseña
                elseif (password_verify($password, $user['password'])) {
                    // Contraseña correcta y usuario verificado
                    // Actualizar última sesión
                    $update_query = "UPDATE users SET last_login = NOW() WHERE id = ?";
                    $update_stmt = $conn->prepare($update_query);
                    $update_stmt->bind_param("i", $user['id']);
                    $update_stmt->execute();
                    $update_stmt->close();

                    // Actualizar estado a online
                    $update_status_query = "INSERT INTO user_status (user_id, status, last_activity) VALUES (?, 'online', NOW()) ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()";
                    $status_stmt = $conn->prepare($update_status_query);
                    $status_stmt->bind_param("i", $user['id']);
                    $status_stmt->execute();
                    $status_stmt->close();

                    // Crear sesión
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['name'] = $user['name'];
                    $_SESSION['phone'] = $phone;

                    $conn->close();
                    header('Location: dashboard.php');
                    exit();
                } else {
                    $error = "Número de teléfono o contraseña incorrectos.";
                }
            } else {
                $error = "Número de teléfono o contraseña incorrectos.";
            }
            $stmt->close();
        }
    }
    $conn->close(); // Cerrar conexión si hubo error de login
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FlyChat - Acceso</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        .blue-gradient { background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%); }
        .button-gradient { background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%); color: white; }
        .button-gradient:hover { background: linear-gradient(135deg, #0077b3 0%, #004494 100%); }
        .button-gradient:disabled { background: linear-gradient(135deg, #a0aec0 0%, #718096 100%); cursor: not-allowed; }
        .tab { cursor: pointer; padding: 10px 15px; border-bottom: 2px solid transparent; }
        .tab.active { border-bottom-color: #0077b3; color: #0077b3; font-weight: 600; }
        /* Estilos para el spinner */
        .spinner {
            border: 4px solid rgba(0, 0, 0, 0.1);
            width: 20px;
            height: 20px;
            border-radius: 50%;
            border-left-color: #fff;
            animation: spin 1s ease infinite;
            display: inline-block;
            margin-right: 5px;
            vertical-align: middle;
        }
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
    </style>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <div class="flex-1 flex flex-col justify-center items-center p-4 sm:p-6">
        <div class="w-full max-w-md bg-white rounded-xl shadow-lg overflow-hidden">
            <!-- Header -->
            <div class="blue-gradient p-6 text-center">
                <h1 class="text-white text-2xl font-bold">FlyChat</h1>
                <p class="text-blue-100 mt-1">Mensajería instantánea privada.</p>
            </div>

            <!-- Tabs -->
            <div class="flex border-b">
                <div id="tab-login" class="tab flex-1 text-center active">Iniciar Sesión</div>
                <div id="tab-register" class="tab flex-1 text-center">Registrarse</div>
            </div>

            <!-- Contenedor de Formularios -->
            <div class="p-6">
                <!-- Mensaje de estado general (para errores o info) -->
                <div id="status-message" class="mb-4 text-sm font-medium p-3 rounded hidden"></div>

                <!-- Formulario de Login (visible por defecto) -->
                <form method="post" id="login-form" class="">
                    <input type="hidden" name="action" value="login">
                    <h2 class="text-xl font-semibold text-gray-800 mb-6">Iniciar sesión</h2>

                    <!-- Campos de Login (teléfono, contraseña) -->
                    <div class="mb-4">
                        <label class="block text-gray-700 text-sm font-medium mb-2" for="login-phone">Número de teléfono</label>
                        <div class="flex">
                            <select name="country_code" id="login-country-code" class="shadow-sm appearance-none border rounded-l-lg py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500 bg-gray-50 w-1/3">
                                <!-- Opciones de país -->
                                <option value="1">+1 (USA)</option>
                                <option value="52">+52 (México)</option>
                                <option value="34">+34 (España)</option>
                                <option value="57" selected>+57 (Colombia)</option>
                                <option value="54">+54 (Argentina)</option>
                                <option value="56">+56 (Chile)</option>
                                <option value="51">+51 (Perú)</option>
                            </select>
                            <input class="shadow-sm appearance-none border rounded-r-lg w-2/3 py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500" id="login-phone" name="phone" type="tel" placeholder="Número" required>
                        </div>
                    </div>
                    <div class="mb-6">
                        <label class="block text-gray-700 text-sm font-medium mb-2" for="login-password">Contraseña</label>
                        <input class="shadow-sm appearance-none border rounded-lg w-full py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500" id="login-password" name="password" type="password" placeholder="********" required>
                    </div>
                    <button type="submit" class="w-full button-gradient font-medium py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50 transition-colors">
                        Iniciar sesión
                    </button>
                    <?php if ($action === 'login' && !empty($error)): ?>
                        <script>
                            // Mostrar error de PHP en el contenedor de estado
                            document.addEventListener('DOMContentLoaded', function() {
                                const statusDiv = document.getElementById('status-message');
                                statusDiv.textContent = <?php echo json_encode($error); ?>;
                                statusDiv.classList.remove('hidden', 'bg-green-100', 'text-green-700');
                                statusDiv.classList.add('bg-red-100', 'text-red-700');
                             });
                        </script>
                    <?php endif; ?>
                </form>

                <!-- Formulario de Registro (oculto por defecto) -->
                <form id="register-form" class="hidden"> <!-- Quitamos method="post" y action -->
                    <h2 class="text-xl font-semibold text-gray-800 mb-6">Registrarse</h2>

                    <!-- Campos iniciales de Registro -->
                    <div id="register-step-1">
                        <div class="mb-4">
                            <label class="block text-gray-700 text-sm font-medium mb-2" for="register-phone">Número de teléfono</label>
                            <div class="flex">
                                <select name="country_code" id="register-country-code" class="shadow-sm appearance-none border rounded-l-lg py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500 bg-gray-50 w-1/3">
                                    <!-- Opciones de país -->
                                    <option value="1">+1 (USA)</option>
                                    <option value="52">+52 (México)</option>
                                    <option value="34">+34 (España)</option>
                                    <option value="57" selected>+57 (Colombia)</option>
                                    <option value="54">+54 (Argentina)</option>
                                    <option value="56">+56 (Chile)</option>
                                    <option value="51">+51 (Perú)</option>
                                </select>
                                <input class="shadow-sm appearance-none border rounded-r-lg w-2/3 py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500" id="register-phone" name="phone" type="tel" placeholder="Número" required>
                            </div>
                        </div>
                        <div class="mb-4">
                            <label class="block text-gray-700 text-sm font-medium mb-2" for="register-name">Tu nombre</label>
                            <input class="shadow-sm appearance-none border rounded-lg w-full py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500" id="register-name" name="name" type="text" placeholder="Nombre completo" required>
                        </div>
                        <div class="mb-4">
                            <label class="block text-gray-700 text-sm font-medium mb-2" for="register-password">Contraseña</label>
                            <input class="shadow-sm appearance-none border rounded-lg w-full py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500" id="register-password" name="password" type="password" placeholder="Mínimo 6 caracteres" required>
                        </div>
                        <div class="mb-6">
                            <label class="block text-gray-700 text-sm font-medium mb-2" for="confirm-password">Confirmar Contraseña</label>
                            <input class="shadow-sm appearance-none border rounded-lg w-full py-3 px-4 text-gray-700 focus:outline-none focus:ring-2 focus:ring-blue-500" id="confirm-password" name="confirm_password" type="password" placeholder="Repite la contraseña" required>
                        </div>
                        <!-- Contenedor para reCAPTCHA (Firebase lo usará) -->
                        <div id="recaptcha-container" class="mb-4"></div>
                        <!-- Botón para iniciar verificación -->
                        <button type="button" id="send-otp-button" class="w-full button-gradient font-medium py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50 transition-colors">
                            <span id="send-otp-text">Enviar código de verificación</span>
                            <span id="send-otp-spinner" class="hidden"><span class="spinner"></span> Enviando...</span>
                        </button>
                    </div>

                    <!-- Paso 2: Ingresar OTP (oculto inicialmente) -->
                    <div id="register-step-2" class="hidden">
                         <p class="text-gray-600 text-sm mb-4">
                            Ingresa el código de 6 dígitos enviado a <strong id="phone-to-verify-display"></strong>.
                         </p>
                         <div class="mb-6">
                            <label class="block text-gray-700 text-sm font-medium mb-2" for="otp-code">Código OTP</label>
                            <input class="shadow-sm appearance-none border rounded-lg w-full py-3 px-4 text-gray-700 text-center tracking-widest text-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                                id="otp-code" name="otp" type="text" inputmode="numeric" pattern="[0-9]*" placeholder="------" required maxlength="6">
                        </div>
                        <button type="button" id="verify-otp-button" class="w-full button-gradient font-medium py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50 transition-colors">
                             <span id="verify-otp-text">Verificar y Registrar</span>
                             <span id="verify-otp-spinner" class="hidden"><span class="spinner"></span> Verificando...</span>
                        </button>
                         <button type="button" id="cancel-otp-button" class="w-full text-center text-sm text-gray-600 hover:text-blue-600 mt-4 py-2">
                             Cancelar / Cambiar número
                         </button>
                    </div>

                </form>
            </div>
        </div>
    </div>

    <!-- Firebase SDK -->
    <script type="module">
      // Import the functions you need from the SDKs
      import { initializeApp } from "https://www.gstatic.com/firebasejs/10.12.2/firebase-app.js"; // Actualiza a la última versión estable si es necesario
      import { getAuth, RecaptchaVerifier, signInWithPhoneNumber } from "https://www.gstatic.com/firebasejs/10.12.2/firebase-auth.js";

      // Your web app's Firebase configuration (Usa tus credenciales reales)
      const firebaseConfig = {
        apiKey: "TU_API_KEY", // REEMPLAZA
        authDomain: "TU_AUTH_DOMAIN", // REEMPLAZA
        projectId: "TU_PROJECT_ID", // REEMPLAZA
        storageBucket: "TU_STORAGE_BUCKET", // REEMPLAZA
        messagingSenderId: "TU_MESSAGING_SENDER_ID", // REEMPLAZA
        appId: "TU_APP_ID", // REEMPLAZA
        // measurementId: "G-XXXXXXXXXX" // Opcional
      };

      // Initialize Firebase
      const app = initializeApp(firebaseConfig);
      const auth = getAuth(app);
      auth.languageCode = 'es'; // Para mensajes en español

      // --- Elementos del DOM ---
      const tabLogin = document.getElementById('tab-login');
      const tabRegister = document.getElementById('tab-register');
      const formLogin = document.getElementById('login-form');
      const formRegister = document.getElementById('register-form');
      const statusMessage = document.getElementById('status-message');

      // Elementos Registro Paso 1
      const registerStep1 = document.getElementById('register-step-1');
      const registerCountryCode = document.getElementById('register-country-code');
      const registerPhoneInput = document.getElementById('register-phone');
      const registerNameInput = document.getElementById('register-name');
      const registerPasswordInput = document.getElementById('register-password');
      const confirmPasswordInput = document.getElementById('confirm-password');
      const recaptchaContainer = document.getElementById('recaptcha-container');
      const sendOtpButton = document.getElementById('send-otp-button');
      const sendOtpText = document.getElementById('send-otp-text');
      const sendOtpSpinner = document.getElementById('send-otp-spinner');

      // Elementos Registro Paso 2
      const registerStep2 = document.getElementById('register-step-2');
      const phoneToVerifyDisplay = document.getElementById('phone-to-verify-display');
      const otpCodeInput = document.getElementById('otp-code');
      const verifyOtpButton = document.getElementById('verify-otp-button');
      const verifyOtpText = document.getElementById('verify-otp-text');
      const verifyOtpSpinner = document.getElementById('verify-otp-spinner');
      const cancelOtpButton = document.getElementById('cancel-otp-button');

      // --- Estado de la App ---
      let confirmationResult = null; // Guardará el resultado de Firebase
      let registrationData = {}; // Guardará name y password temporalmente

      // --- Funciones Auxiliares ---
      function showStatus(message, isError = true) {
          statusMessage.textContent = message;
          statusMessage.classList.remove('hidden');
          if (isError) {
              statusMessage.classList.remove('bg-green-100', 'text-green-700');
              statusMessage.classList.add('bg-red-100', 'text-red-700');
          } else {
              statusMessage.classList.remove('bg-red-100', 'text-red-700');
              statusMessage.classList.add('bg-green-100', 'text-green-700');
          }
      }

      function hideStatus() {
          statusMessage.classList.add('hidden');
          statusMessage.textContent = '';
      }

      function showSpinner(button, textElement, spinnerElement) {
          textElement.classList.add('hidden');
          spinnerElement.classList.remove('hidden');
          button.disabled = true;
      }

      function hideSpinner(button, textElement, spinnerElement) {
          textElement.classList.remove('hidden');
          spinnerElement.classList.add('hidden');
          button.disabled = false;
      }

      // --- Lógica de Tabs ---
      function showLogin() {
          formLogin.classList.remove('hidden');
          formRegister.classList.add('hidden');
          tabLogin.classList.add('active');
          tabRegister.classList.remove('active');
          hideStatus(); // Limpiar mensajes al cambiar
          resetRegistrationForm(); // Resetear estado de registro si se cambia
      }

      function showRegister() {
          formLogin.classList.add('hidden');
          formRegister.classList.remove('hidden');
          tabLogin.classList.remove('active');
          tabRegister.classList.add('active');
          hideStatus(); // Limpiar mensajes al cambiar
      }

      tabLogin.addEventListener('click', showLogin);
      tabRegister.addEventListener('click', showRegister);

       // --- Lógica de Registro con Firebase ---

       // 1. Configurar reCAPTCHA Verifier
       function setupRecaptcha() {
          // Limpiar contenedor por si acaso
          recaptchaContainer.innerHTML = '';
          // Es importante que 'recaptcha-container' esté visible al llamar a render()
          // Usamos try-catch porque puede fallar si ya existe uno
          try {
            window.recaptchaVerifier = new RecaptchaVerifier(auth, 'recaptcha-container', {
              'size': 'invisible', // Puedes cambiar a 'normal' si prefieres visible
              'callback': (response) => {
                // reCAPTCHA resuelto, usualmente no se necesita acción aquí con invisible
                console.log("reCAPTCHA solved");
              },
              'expired-callback': () => {
                showStatus('El verificador reCAPTCHA ha expirado. Por favor, inténtalo de nuevo.');
                hideSpinner(sendOtpButton, sendOtpText, sendOtpSpinner);
                // Podrías resetear el reCAPTCHA aquí si fuera necesario
              },
              'error-callback': (error) => {
                console.error("Recaptcha error:", error);
                showStatus('Error en la verificación reCAPTCHA. Revisa la configuración de dominios autorizados en Firebase.');
                hideSpinner(sendOtpButton, sendOtpText, sendOtpSpinner);
              }
            });
            // Renderizar explícitamente si es invisible
            window.recaptchaVerifier.render().then((widgetId) => {
                 window.recaptchaWidgetId = widgetId;
                 console.log("reCAPTCHA rendered, widgetId:", widgetId);
             }).catch(error => {
                 console.error("Error rendering reCAPTCHA:", error);
                 showStatus('No se pudo mostrar el verificador reCAPTCHA. Intenta recargar la página.');
                 hideSpinner(sendOtpButton, sendOtpText, sendOtpSpinner);
             });
          } catch (e) {
            console.warn("Error setting up reCAPTCHA (might already exist):", e);
             // Si ya existe, intenta usar el existente. Si no, muestra error.
             if (!window.recaptchaVerifier) {
                 showStatus('Error al inicializar la verificación reCAPTCHA.');
                  hideSpinner(sendOtpButton, sendOtpText, sendOtpSpinner);
             }
          }
       }

      // Llamar a setupRecaptcha cuando se muestra el formulario de registro
      tabRegister.addEventListener('click', setupRecaptcha);
      // También al cargar la página si el tab de registro está activo por defecto (no es el caso aquí)
      // if (tabRegister.classList.contains('active')) { setupRecaptcha(); }


      // 2. Enviar OTP
      sendOtpButton.addEventListener('click', () => {
          hideStatus();
          const phone = registerPhoneInput.value.trim();
          const name = registerNameInput.value.trim();
          const password = registerPasswordInput.value;
          const confirmPassword = confirmPasswordInput.value;

          // Validaciones básicas
          if (!phone || !name || !password || !confirmPassword) {
              showStatus('Todos los campos son requeridos.');
              return;
          }
          if (password !== confirmPassword) {
              showStatus('Las contraseñas no coinciden.');
              return;
          }
           if (password.length < 6) {
               showStatus('La contraseña debe tener al menos 6 caracteres.');
               return;
           }
          // Asegurarse de que el reCAPTCHA esté listo
          if (!window.recaptchaVerifier) {
              showStatus('El verificador reCAPTCHA no está listo. Espera un momento o recarga.');
              setupRecaptcha(); // Intenta configurarlo de nuevo
              return;
          }

          const countryCode = registerCountryCode.value;
          const formattedPhone = `+${countryCode}${phone}`;

          showSpinner(sendOtpButton, sendOtpText, sendOtpSpinner);

          signInWithPhoneNumber(auth, formattedPhone, window.recaptchaVerifier)
              .then((result) => {
                  hideSpinner(sendOtpButton, sendOtpText, sendOtpSpinner);
                  console.log("OTP Sent, confirmationResult:", result);
                  confirmationResult = result; // Guardar para el siguiente paso
                  registrationData = { name, password }; // Guardar datos temporalmente

                  // Cambiar a la vista de OTP
                  registerStep1.classList.add('hidden');
                  registerStep2.classList.remove('hidden');
                  phoneToVerifyDisplay.textContent = formattedPhone;
                  showStatus(`Código enviado a ${formattedPhone}.`, false); // Mensaje de éxito
                  otpCodeInput.focus();

              }).catch((error) => {
                  hideSpinner(sendOtpButton, sendOtpText, sendOtpSpinner);
                  console.error("Error sending OTP:", error);
                  // Manejar errores comunes de Firebase Auth
                  let userMessage = 'Error al enviar el código OTP. Inténtalo de nuevo.';
                   if (error.code === 'auth/invalid-phone-number') {
                       userMessage = 'El número de teléfono no es válido.';
                   } else if (error.code === 'auth/too-many-requests') {
                       userMessage = 'Demasiados intentos. Por favor, inténtalo más tarde.';
                   } else if (error.code === 'auth/captcha-check-failed') {
                       userMessage = 'Falló la verificación reCAPTCHA. Inténtalo de nuevo.';
                       // Resetear reCAPTCHA si falló
                       window.recaptchaVerifier.render().then((widgetId) => {
                           if(window.grecaptcha) grecaptcha.reset(widgetId);
                       });
                   } else if (error.message.includes("auth/network-request-failed")){
                       userMessage = 'Error de red. Verifica tu conexión a internet.';
                   }
                   // Agrega más códigos de error según necesites:
                   // https://firebase.google.com/docs/auth/admin/errors

                  showStatus(userMessage);

                   // Asegurarse de que el reCAPTCHA se resetee para el próximo intento si es necesario
                  if (window.grecaptcha && window.recaptchaWidgetId) {
                     try {
                       grecaptcha.reset(window.recaptchaWidgetId);
                     } catch(e){ console.warn("Couldn't reset recaptcha", e);}
                  } else if (window.recaptchaVerifier) {
                      // Si es invisible y no tenemos el widgetId explícito, re-render podría funcionar
                     window.recaptchaVerifier.render().catch(e => console.warn("Couldn't re-render recaptcha", e));
                  }


              });
      });

      // 3. Verificar OTP y Finalizar Registro
      verifyOtpButton.addEventListener('click', () => {
            hideStatus();
            const otpCode = otpCodeInput.value.trim();

            if (otpCode.length !== 6 || !/^\d{6}$/.test(otpCode)) {
                 showStatus('Ingresa un código OTP válido de 6 dígitos.');
                 return;
            }
            if (!confirmationResult) {
                 showStatus('Error: No se encontró la confirmación de envío. Intenta enviar el código de nuevo.');
                 return;
            }

            showSpinner(verifyOtpButton, verifyOtpText, verifyOtpSpinner);

            confirmationResult.confirm(otpCode)
                .then((result) => {
                    // ¡Usuario verificado por Firebase!
                    console.log("User signed in successfully by Firebase:", result.user);
                    const user = result.user;

                    // Obtener el ID Token
                    user.getIdToken().then((idToken) => {
                         console.log("Got ID Token:", idToken);

                         // Enviar token y datos de registro al backend
                         const backendData = new FormData();
                         backendData.append('idToken', idToken);
                         backendData.append('name', registrationData.name);
                         backendData.append('password', registrationData.password); // Enviar contraseña en texto plano aquí (Backend la hasheará)

                         fetch('finalize_registration.php', {
                             method: 'POST',
                             body: backendData
                         })
                         .then(response => {
                             if (!response.ok) {
                                 // Si el servidor responde con error (4xx, 5xx)
                                 return response.json().then(errData => {
                                     throw new Error(errData.message || `Error del servidor: ${response.status}`);
                                 });
                             }
                             return response.json();
                         })
                         .then(data => {
                             hideSpinner(verifyOtpButton, verifyOtpText, verifyOtpSpinner);
                             if (data.success && data.redirect) {
                                 showStatus('¡Registro completado! Redirigiendo...', false);
                                 // Redirigir al dashboard
                                 window.location.href = data.redirect;
                             } else {
                                 // Mostrar error del backend
                                 showStatus(data.message || 'Error al finalizar el registro en el servidor.');
                                 // Opcional: ¿volver al paso 1 o permitir reintentar OTP?
                                 // Por ahora, mostramos error y el usuario podría cancelar.
                             }
                         })
                         .catch(error => {
                             hideSpinner(verifyOtpButton, verifyOtpText, verifyOtpSpinner);
                             console.error('Error finalizing registration:', error);
                             showStatus(`Error al conectar con el servidor: ${error.message}`);
                         });

                    }).catch((error) => {
                         // Error al obtener ID token
                         hideSpinner(verifyOtpButton, verifyOtpText, verifyOtpSpinner);
                         console.error('Error getting ID token:', error);
                         showStatus('Error al obtener token de verificación. Inténtalo de nuevo.');
                    });

                }).catch((error) => {
                    // Error al confirmar OTP con Firebase
                    hideSpinner(verifyOtpButton, verifyOtpText, verifyOtpSpinner);
                    console.error("Error confirming OTP:", error);
                     let userMessage = 'Error al verificar el código OTP.';
                     if (error.code === 'auth/invalid-verification-code') {
                         userMessage = 'El código de verificación no es válido.';
                     } else if (error.code === 'auth/code-expired') {
                         userMessage = 'El código de verificación ha expirado. Por favor, solicita uno nuevo.';
                         // Podrías forzar volver al paso 1 aquí
                         resetRegistrationForm();
                     }
                    showStatus(userMessage);
                    otpCodeInput.focus();
                    otpCodeInput.select();
                });
      });

      // 4. Botón Cancelar/Cambiar número en Paso 2
       cancelOtpButton.addEventListener('click', () => {
           resetRegistrationForm();
       });

       // Función para resetear el formulario de registro a su estado inicial
       function resetRegistrationForm() {
           registerStep1.classList.remove('hidden');
           registerStep2.classList.add('hidden');
           hideStatus();
           confirmationResult = null;
           registrationData = {};
           // registerPhoneInput.value = ''; // Decide si quieres limpiar campos
           // registerNameInput.value = '';
           // registerPasswordInput.value = '';
           // confirmPasswordInput.value = '';
           otpCodeInput.value = '';
           // Es importante resetear o re-renderizar reCAPTCHA aquí también
           if (window.recaptchaVerifier && window.grecaptcha && window.recaptchaWidgetId) {
               try{ grecaptcha.reset(window.recaptchaWidgetId); } catch(e) {console.warn("Couldn't reset captcha", e);}
           } else {
               setupRecaptcha(); // Reintentar configuración completa
           }

           hideSpinner(sendOtpButton, sendOtpText, sendOtpSpinner); // Asegurar que spinner esté oculto
           hideSpinner(verifyOtpButton, verifyOtpText, verifyOtpSpinner);
       }


       // Inicializar la vista correcta al cargar
       // (El código PHP ya maneja si hubo error de login)
       // Por defecto, se muestra el login.

    </script>

</body>
</html>