<?php
require_once 'vendor/autoload.php';
require_once 'config.php';

use Ratchet\Server\IoServer;
use Ratchet\Http\HttpServer;
use Ratchet\WebSocket\WsServer;
use React\EventLoop\Factory;
use React\Socket\Server as SocketServer;

class EnhancedChat implements \Ratchet\MessageComponentInterface {
    protected $clients;
    protected $users;
    protected $conn;
    protected $calls;

    public function __construct() {
        $this->clients = new \SplObjectStorage;
        $this->users = [];
        $this->calls = [];
        global $conn;
        $this->conn = $conn;
        echo "Servidor de chat inicializado\n";
    }

    public function onOpen(\Ratchet\ConnectionInterface $conn) {
        $this->clients->attach($conn);
        echo "Nueva conexión! ({$conn->resourceId})\n";
    }

    public function onMessage(\Ratchet\ConnectionInterface $from, $msg) {
        try {
            $data = json_decode($msg);
            
            if (!isset($data->type)) {
                echo "Mensaje recibido sin tipo definido\n";
                return;
            }
            
            switch($data->type) {
                case 'auth':
                    $this->handleAuth($from, $data);
                    break;
                
                case 'message':
                    $this->handleMessage($from, $data);
                    break;
                
                case 'typing':
                    $this->handleTyping($from, $data);
                    break;
                
                case 'read':
                    $this->handleReadReceipt($from, $data);
                    break;
                
                case 'status':
                    $this->handleStatusUpdate($from, $data);
                    break;
                
                case 'call_request':
                    $this->handleCallRequest($from, $data);
                    break;
                
                case 'call_response':
                    $this->handleCallResponse($from, $data);
                    break;
                
                case 'call_end':
                    $this->handleCallEnd($from, $data);
                    break;
                
                case 'heartbeat':
                    $this->handleHeartbeat($from, $data);
                    break;
                
                default:
                    echo "Tipo de mensaje desconocido: {$data->type}\n";
            }
        } catch (\Exception $e) {
            echo "Error al procesar mensaje: " . $e->getMessage() . "\n";
        }
    }

    protected function handleAuth(\Ratchet\ConnectionInterface $conn, $data) {
        if (!isset($data->user_id) || !is_numeric($data->user_id)) {
            echo "Error de autenticación: user_id inválido\n";
            return;
        }
        
        $user_id = (int)$data->user_id;
        $this->users[$conn->resourceId] = $user_id;
        
        // Actualizar estado de usuario a 'online'
        $stmt = $this->conn->prepare("INSERT INTO user_status (user_id, status) VALUES (?, 'online') 
                                    ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()");
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        $stmt->close();
        
        // Notificar a otros usuarios que este usuario está en línea
        $this->broadcastUserStatus($user_id, 'online');
        
        // Enviar lista de usuarios en línea a este usuario
        $online_users = $this->getOnlineUsers();
        $conn->send(json_encode([
            'type' => 'auth_success',
            'online_users' => $online_users
        ]));
        
        echo "Usuario {$user_id} autenticado en conexión {$conn->resourceId}\n";
    }

    protected function handleMessage(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            echo "Mensaje recibido de usuario no autenticado\n";
            return;
        }
        
        if (!isset($data->receiver_id) || !isset($data->message)) {
            echo "Mensaje incompleto recibido\n";
            return;
        }
        
        $sender_id = $this->users[$from->resourceId];
        $receiver_id = (int)$data->receiver_id;
        $message = $data->message;
        $message_type = isset($data->message_type) ? $data->message_type : 'text';
        
        // Parámetros opcionales para archivos
        $file_url = isset($data->file_url) ? $data->file_url : null;
        $file_name = isset($data->file_name) ? $data->file_name : null;
        $file_size = isset($data->file_size) ? (int)$data->file_size : null;
        $file_type = isset($data->file_type) ? $data->file_type : null;
        
        // ID temporal para actualización posterior
        $temp_id = isset($data->temp_id) ? $data->temp_id : null;
        
        // Guardar mensaje en la base de datos
        $stmt = $this->conn->prepare("INSERT INTO messages (sender_id, receiver_id, message, type, file_url, file_name, file_size, file_type) 
                                     VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
        $stmt->bind_param("iisssssi", $sender_id, $receiver_id, $message, $message_type, $file_url, $file_name, $file_size, $file_type);
        $stmt->execute();
        $message_id = $this->conn->insert_id;
        $stmt->close();
        
        // Actualizar como entregado si el receptor está en línea
        $delivered = false;
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $receiver_id) {
                $delivered = true;
                break;
            }
        }
        
        if ($delivered) {
            $update_stmt = $this->conn->prepare("UPDATE messages SET delivered = 1 WHERE id = ?");
            $update_stmt->bind_param("i", $message_id);
            $update_stmt->execute();
            $update_stmt->close();
        }
        
        // Enviar al destinatario si está en línea
        $message_sent = false;
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $receiver_id) {
                $client->send(json_encode([
                    'type' => 'message',
                    'message_id' => $message_id,
                    'sender_id' => $sender_id,
                    'message' => $message,
                    'message_type' => $message_type,
                    'file_url' => $file_url,
                    'file_name' => $file_name,
                    'file_size' => $file_size,
                    'file_type' => $file_type,
                    'timestamp' => date('Y-m-d H:i:s')
                ]));
                $message_sent = true;
            }
        }
        
        // Enviar confirmación al remitente
        $from->send(json_encode([
            'type' => 'sent',
            'message_id' => $message_id,
            'temp_id' => $temp_id,
            'receiver_id' => $receiver_id,
            'delivered' => $delivered,
            'timestamp' => date('Y-m-d H:i:s')
        ]));
        
        echo "Mensaje enviado de {$sender_id} a {$receiver_id} (ID: {$message_id})\n";
    }

    protected function handleTyping(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            return;
        }
        
        if (!isset($data->receiver_id) || !isset($data->typing)) {
            return;
        }
        
        $sender_id = $this->users[$from->resourceId];
        $receiver_id = (int)$data->receiver_id;
        $typing = (bool)$data->typing;
        
        // Notificar al destinatario
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $receiver_id) {
                $client->send(json_encode([
                    'type' => 'typing',
                    'sender_id' => $sender_id,
                    'typing' => $typing
                ]));
                break;
            }
        }
    }

    protected function handleReadReceipt(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            return;
        }
        
        if (!isset($data->message_ids) || !is_array($data->message_ids) || !isset($data->sender_id)) {
            return;
        }
        
        $reader_id = $this->users[$from->resourceId];
        $sender_id = (int)$data->sender_id;
        $message_ids = array_map('intval', $data->message_ids);
        
        if (empty($message_ids)) {
            return;
        }
        
        // Marcar mensajes como leídos
        $ids_str = implode(',', $message_ids);
        $stmt = $this->conn->prepare("UPDATE messages SET `read` = 1 WHERE id IN ({$ids_str}) AND sender_id = ? AND receiver_id = ?");
        $stmt->bind_param("ii", $sender_id, $reader_id);
        $stmt->execute();
        $stmt->close();
        
        // Notificar al remitente original
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $sender_id) {
                $client->send(json_encode([
                    'type' => 'read',
                    'reader_id' => $reader_id,
                    'message_ids' => $message_ids
                ]));
                break;
            }
        }
        
        echo "Mensajes marcados como leídos: " . $ids_str . "\n";
    }

    protected function handleStatusUpdate(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            return;
        }
        
        if (!isset($data->status) || !in_array($data->status, ['online', 'away', 'offline'])) {
            return;
        }
        
        $user_id = $this->users[$from->resourceId];
        $status = $data->status;
        
        // Actualizar estado de usuario
        $stmt = $this->conn->prepare("UPDATE user_status SET status = ?, last_activity = NOW() WHERE user_id = ?");
        $stmt->bind_param("si", $status, $user_id);
        $stmt->execute();
        $stmt->close();
        
        // Notificar a otros usuarios
        $this->broadcastUserStatus($user_id, $status);
        
        echo "Estado de usuario {$user_id} actualizado a: {$status}\n";
    }

    protected function handleCallRequest(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            return;
        }
        
        if (!isset($data->receiver_id) || !isset($data->call_type) || !in_array($data->call_type, ['audio', 'video'])) {
            return;
        }
        
        $caller_id = $this->users[$from->resourceId];
        $receiver_id = (int)$data->receiver_id;
        $call_type = $data->call_type;
        
        // Registrar llamada en la base de datos
        $stmt = $this->conn->prepare("INSERT INTO calls (caller_id, receiver_id, call_type, status) VALUES (?, ?, ?, 'ringing')");
        $stmt->bind_param("iis", $caller_id, $receiver_id, $call_type);
        $stmt->execute();
        $call_id = $this->conn->insert_id;
        $stmt->close();
        
        // Almacenar información de la llamada
        $this->calls[$call_id] = [
            'caller_id' => $caller_id,
            'receiver_id' => $receiver_id,
            'call_type' => $call_type,
            'status' => 'ringing',
            'start_time' => null,
            'call_id' => $call_id
        ];
        
        // Notificar al receptor
        $receiver_found = false;
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $receiver_id) {
                $client->send(json_encode([
                    'type' => 'call_incoming',
                    'call_id' => $call_id,
                    'caller_id' => $caller_id,
                    'call_type' => $call_type
                ]));
                $receiver_found = true;
                break;
            }
        }
        
        // Confirmar al llamante
        $from->send(json_encode([
            'type' => 'call_initiated',
            'call_id' => $call_id,
            'receiver_id' => $receiver_id,
            'receiver_available' => $receiver_found,
            'call_type' => $call_type
        ]));
        
        echo "Llamada {$call_id} iniciada: {$caller_id} llamando a {$receiver_id} ({$call_type})\n";
    }

    protected function handleCallResponse(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            return;
        }
        
        if (!isset($data->call_id) || !isset($data->response) || !in_array($data->response, ['accept', 'reject'])) {
            return;
        }
        
        $responder_id = $this->users[$from->resourceId];
        $call_id = (int)$data->call_id;
        $response = $data->response;
        
        // Verificar que la llamada exista
        if (!isset($this->calls[$call_id])) {
            echo "Llamada {$call_id} no encontrada\n";
            return;
        }
        
        $call = $this->calls[$call_id];
        
        // Verificar que el respondedor sea el receptor de la llamada
        if ($responder_id != $call['receiver_id']) {
            echo "Error: El usuario {$responder_id} no es el receptor de la llamada {$call_id}\n";
            return;
        }
        
        // Actualizar estado de la llamada
        $status = ($response == 'accept') ? 'ongoing' : 'rejected';
        $stmt = $this->conn->prepare("UPDATE calls SET status = ?, start_time = " . ($status == 'ongoing' ? "NOW()" : "NULL") . " WHERE id = ?");
        $stmt->bind_param("si", $status, $call_id);
        $stmt->execute();
        $stmt->close();
        
        $this->calls[$call_id]['status'] = $status;
        
        if ($status == 'ongoing') {
            $this->calls[$call_id]['start_time'] = date('Y-m-d H:i:s');
        }
        
        // Notificar al llamante
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $call['caller_id']) {
                $client->send(json_encode([
                    'type' => 'call_response',
                    'call_id' => $call_id,
                    'response' => $response,
                    'responder_id' => $responder_id
                ]));
                
                // Si se aceptó, incluir información de señalización para WebRTC
                if ($response == 'accept' && isset($data->sdp)) {
                    $client->send(json_encode([
                        'type' => 'webrtc_signal',
                        'call_id' => $call_id,
                        'from_id' => $responder_id,
                        'sdp' => $data->sdp
                    ]));
                }
                
                break;
            }
        }
        
        echo "Llamada {$call_id} " . ($status == 'ongoing' ? "aceptada" : "rechazada") . " por {$responder_id}\n";
    }

    protected function handleCallEnd(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            return;
        }
        
        if (!isset($data->call_id)) {
            return;
        }
        
        $user_id = $this->users[$from->resourceId];
        $call_id = (int)$data->call_id;
        
        // Verificar que la llamada exista
        if (!isset($this->calls[$call_id])) {
            echo "Llamada {$call_id} no encontrada\n";
            return;
        }
        
        $call = $this->calls[$call_id];
        
        // Verificar que el usuario sea parte de la llamada
        if ($user_id != $call['caller_id'] && $user_id != $call['receiver_id']) {
            echo "Error: El usuario {$user_id} no es parte de la llamada {$call_id}\n";
            return;
        }
        
        // Actualizar estado de la llamada
        $stmt = $this->conn->prepare("UPDATE calls SET status = 'ended', end_time = NOW() WHERE id = ?");
        $stmt->bind_param("i", $call_id);
        $stmt->execute();
        $stmt->close();
        
        // Notificar al otro participante
        $other_id = ($user_id == $call['caller_id']) ? $call['receiver_id'] : $call['caller_id'];
        
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $other_id) {
                $client->send(json_encode([
                    'type' => 'call_ended',
                    'call_id' => $call_id,
                    'ended_by' => $user_id
                ]));
                break;
            }
        }
        
        // Eliminar registro de llamada
        unset($this->calls[$call_id]);
        
        echo "Llamada {$call_id} finalizada por {$user_id}\n";
    }

    protected function handleHeartbeat(\Ratchet\ConnectionInterface $from, $data) {
        if (!isset($this->users[$from->resourceId])) {
            return;
        }
        
        $user_id = $this->users[$from->resourceId];
        
        // Actualizar última actividad
        $stmt = $this->conn->prepare("UPDATE user_status SET last_activity = NOW() WHERE user_id = ?");
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        $stmt->close();
    }

    protected function getOnlineUsers() {
        $online_users = [];
        $user_ids = array_values($this->users);
        
        if (empty($user_ids)) {
            return $online_users;
        }
        
        $ids_str = implode(',', $user_ids);
        $stmt = $this->conn->prepare("SELECT user_id, status FROM user_status WHERE user_id IN ({$ids_str})");
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($row = $result->fetch_assoc()) {
            $online_users[] = [
                'user_id' => (int)$row['user_id'],
                'status' => $row['status']
            ];
        }
        
        $stmt->close();
        return $online_users;
    }

    protected function broadcastUserStatus($user_id, $status) {
        foreach ($this->clients as $client) {
            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] != $user_id) {
                $client->send(json_encode([
                    'type' => 'user_status',
                    'user_id' => $user_id,
                    'status' => $status
                ]));
            }
        }
    }

    public function onClose(\Ratchet\ConnectionInterface $conn) {
        if (isset($this->users[$conn->resourceId])) {
            $user_id = $this->users[$conn->resourceId];
            
            // Verificar si el usuario tiene otra conexión activa
            $user_has_other_connection = false;
            foreach ($this->clients as $client) {
                if ($client !== $conn && isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $user_id) {
                    $user_has_other_connection = true;
                    break;
                }
            }
            
            // Si no tiene otra conexión, actualizar su estado a offline
            if (!$user_has_other_connection) {
                $stmt = $this->conn->prepare("UPDATE user_status SET status = 'offline', last_activity = NOW() WHERE user_id = ?");
                $stmt->bind_param("i", $user_id);
                $stmt->execute();
                $stmt->close();
                
                // Finalizar llamadas activas
                foreach ($this->calls as $call_id => $call) {
                    if (($call['caller_id'] == $user_id || $call['receiver_id'] == $user_id) && $call['status'] == 'ongoing') {
                        $stmt = $this->conn->prepare("UPDATE calls SET status = 'ended', end_time = NOW() WHERE id = ?");
                        $stmt->bind_param("i", $call_id);
                        $stmt->execute();
                        $stmt->close();
                        
                        $other_id = ($call['caller_id'] == $user_id) ? $call['receiver_id'] : $call['caller_id'];
                        
                        foreach ($this->clients as $client) {
                            if (isset($this->users[$client->resourceId]) && $this->users[$client->resourceId] == $other_id) {
                                $client->send(json_encode([
                                    'type' => 'call_ended',
                                    'call_id' => $call_id,
                                    'reason' => 'disconnected'
                                ]));
                                break;
                            }
                        }
                        
                        unset($this->calls[$call_id]);
                    }
                }
                
                // Notificar a otros usuarios
                $this->broadcastUserStatus($user_id, 'offline');
                
                echo "Usuario {$user_id} desconectado\n";
            }
            
            unset($this->users[$conn->resourceId]);
        }
        
        $this->clients->detach($conn);
        echo "Conexión {$conn->resourceId} cerrada\n";
    }

    public function onError(\Ratchet\ConnectionInterface $conn, \Exception $e) {
        echo "Error: {$e->getMessage()}\n";
        $conn->close();
    }
}

// Crear un loop de eventos
$loop = Factory::create();
$socket = new SocketServer('0.0.0.0:8080', $loop);
$server = new IoServer(
    new HttpServer(
        new WsServer(
            new EnhancedChat()
        )
    ),
    $socket,
    $loop
);

echo "Servidor WebSocket iniciado en puerto 8080\n";
$server->run();